==> jc-1.4.0.tar.gz: java/lang/reflect/ReflectPermission.h <==
// public final class java.lang.reflect.ReflectPermission

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 217a96fa40004e5 java_lang_reflect_ReflectPermission
// @dep_class d5158e4c9a3bab21 java_security_BasicPermission
// @dep_class 2377c76e79058a72 java_security_Permission

// header file dependencies
// @dep_header java_security_BasicPermission

#include "java/security/BasicPermission.h"

#ifndef _JC_java_lang_reflect_ReflectPermission_H_
#define _JC_java_lang_reflect_ReflectPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_reflect_ReflectPermission$sub_refs	_jc_java_lang_reflect_ReflectPermission$sub_refs;
typedef struct _jc_java_lang_reflect_ReflectPermission$sub_nonrefs	_jc_java_lang_reflect_ReflectPermission$sub_nonrefs;
typedef struct _jc_java_lang_reflect_ReflectPermission$refs	_jc_java_lang_reflect_ReflectPermission$refs;
typedef struct _jc_java_lang_reflect_ReflectPermission$nonrefs	_jc_java_lang_reflect_ReflectPermission$nonrefs;
typedef struct _jc_java_lang_reflect_ReflectPermission$object	_jc_java_lang_reflect_ReflectPermission$object;

typedef struct _jc_java_lang_reflect_ReflectPermission$fields_struct	_jc_java_lang_reflect_ReflectPermission$fields_struct;
typedef const struct _jc_java_lang_reflect_ReflectPermission$vmethods	_jc_java_lang_reflect_ReflectPermission$vmethods;
typedef const struct _jc_java_lang_reflect_ReflectPermission$vtable	_jc_java_lang_reflect_ReflectPermission$vtable;
typedef const struct _jc_java_lang_reflect_ReflectPermission$vtype	_jc_java_lang_reflect_ReflectPermission$vtype;

// Class fields structure
struct _jc_java_lang_reflect_ReflectPermission$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_reflect_ReflectPermission$fields_struct _jc_java_lang_reflect_ReflectPermission$class_fields;

// Constructors
extern void _jc_java_lang_reflect_ReflectPermission$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_reflect_ReflectPermission$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_lang_reflect_ReflectPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_lang_reflect_ReflectPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_reflect_ReflectPermission$vmethods {
};

// Vtable
struct _jc_java_lang_reflect_ReflectPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_BasicPermission$vmethods	java_security_BasicPermission;
	_jc_java_lang_reflect_ReflectPermission$vmethods	java_lang_reflect_ReflectPermission;
};

// Vtype
struct _jc_java_lang_reflect_ReflectPermission$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_ReflectPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_ReflectPermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_ReflectPermission$refs {
    _jc_java_lang_reflect_ReflectPermission$sub_refs	java_lang_reflect_ReflectPermission;
    _jc_java_security_BasicPermission$sub_refs	java_security_BasicPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_ReflectPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_ReflectPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_BasicPermission$sub_nonrefs	java_security_BasicPermission;
    _jc_java_lang_reflect_ReflectPermission$sub_nonrefs	java_lang_reflect_ReflectPermission;
};

// Object instance structure
struct _jc_java_lang_reflect_ReflectPermission$object {
	_jc_java_lang_reflect_ReflectPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_ReflectPermission$vtype	*vtype;
	_jc_java_lang_reflect_ReflectPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_ReflectPermission$vtype _jc_java_lang_reflect_ReflectPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_ReflectPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_ReflectPermission$class_object;

#endif	/* _JC_java_lang_reflect_ReflectPermission_H_ */

==> jc-1.4.6.tar.gz: java/lang/reflect/ReflectPermission.h <==
// public final class java.lang.reflect.ReflectPermission

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 217a96fa40004e5 java_lang_reflect_ReflectPermission
// @dep_class d5158e4c9a3bab21 java_security_BasicPermission
// @dep_class 2377c76e79058a72 java_security_Permission

// header file dependencies
// @dep_header java_security_BasicPermission

#include "java/security/BasicPermission.h"

#ifndef _JC_java_lang_reflect_ReflectPermission_H_
#define _JC_java_lang_reflect_ReflectPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_reflect_ReflectPermission$sub_refs	_jc_java_lang_reflect_ReflectPermission$sub_refs;
typedef struct _jc_java_lang_reflect_ReflectPermission$sub_nonrefs	_jc_java_lang_reflect_ReflectPermission$sub_nonrefs;
typedef struct _jc_java_lang_reflect_ReflectPermission$refs	_jc_java_lang_reflect_ReflectPermission$refs;
typedef struct _jc_java_lang_reflect_ReflectPermission$nonrefs	_jc_java_lang_reflect_ReflectPermission$nonrefs;
typedef struct _jc_java_lang_reflect_ReflectPermission$object	_jc_java_lang_reflect_ReflectPermission$object;

typedef struct _jc_java_lang_reflect_ReflectPermission$fields_struct	_jc_java_lang_reflect_ReflectPermission$fields_struct;
typedef const struct _jc_java_lang_reflect_ReflectPermission$vmethods	_jc_java_lang_reflect_ReflectPermission$vmethods;
typedef const struct _jc_java_lang_reflect_ReflectPermission$vtable	_jc_java_lang_reflect_ReflectPermission$vtable;
typedef const struct _jc_java_lang_reflect_ReflectPermission$vtype	_jc_java_lang_reflect_ReflectPermission$vtype;

// Class fields structure
struct _jc_java_lang_reflect_ReflectPermission$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_reflect_ReflectPermission$fields_struct _jc_java_lang_reflect_ReflectPermission$class_fields;

// Constructors
extern void _jc_java_lang_reflect_ReflectPermission$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_reflect_ReflectPermission$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_reflect_ReflectPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_lang_reflect_ReflectPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_reflect_ReflectPermission$vmethods {
};

// Vtable
struct _jc_java_lang_reflect_ReflectPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_BasicPermission$vmethods	java_security_BasicPermission;
	_jc_java_lang_reflect_ReflectPermission$vmethods	java_lang_reflect_ReflectPermission;
};

// Vtype
struct _jc_java_lang_reflect_ReflectPermission$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_ReflectPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_ReflectPermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_ReflectPermission$refs {
    _jc_java_lang_reflect_ReflectPermission$sub_refs	java_lang_reflect_ReflectPermission;
    _jc_java_security_BasicPermission$sub_refs	java_security_BasicPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_ReflectPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_ReflectPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_BasicPermission$sub_nonrefs	java_security_BasicPermission;
    _jc_java_lang_reflect_ReflectPermission$sub_nonrefs	java_lang_reflect_ReflectPermission;
};

// Object instance structure
struct _jc_java_lang_reflect_ReflectPermission$object {
	_jc_java_lang_reflect_ReflectPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_ReflectPermission$vtype	*vtype;
	_jc_java_lang_reflect_ReflectPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_ReflectPermission$vtype _jc_java_lang_reflect_ReflectPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_ReflectPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_ReflectPermission$class_object;

#endif	/* _JC_java_lang_reflect_ReflectPermission_H_ */
